==> nextcloud-20.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/ru.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Недавние статусы",
    "In a meeting" : "На встрече",
    "Commuting" : "В пути",
    "Out sick" : "Болею",
    "Vacationing" : "В отпуске",
    "Working remotely" : "Удалённая работа",
    "User status" : "Статус пользователя",
    "Clear status message after" : "Очистить сообщение о состоянии через",
    "What's your status?" : "Укажите свой статус",
    "Set status" : "Задать статус",
    "Online status" : "Состояние на связи",
    "Status message" : "Сообщение о состоянии",
    "Clear status message" : "Очистить сообщение о состоянии",
    "Set status message" : "Установить сообщение о состоянии",
    "There was an error saving the status" : "Не удалось сохранить статус",
    "There was an error clearing the status" : "Не удалось убрать статус",
    "No recent status changes" : "Недавние изменения статуса отсуствуют ",
    "Away" : "Отсутствует",
    "Do not disturb" : "Не беспокоить",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Не очищать",
    "Today" : "Сегодня",
    "This week" : "Эта неделя",
    "Online" : "На связи",
    "Invisible" : "Невидимка",
    "Offline" : "Автономно",
    "There was an error saving the new status" : "Не удалось сохранить новый статус",
    "30 minutes" : "30 минут",
    "1 hour" : "1 час",
    "4 hours" : "4 часа",
    "Mute all notifications" : "Отключить все уведомления",
    "Clear status after" : "Удалить статус через"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/user_status/l10n/ru.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Недавние статусы",
    "In a meeting" : "На встрече",
    "Commuting" : "В пути",
    "Out sick" : "Болею",
    "Vacationing" : "В отпуске",
    "Working remotely" : "Удалённая работа",
    "User status" : "Статус пользователя",
    "Clear status message after" : "Очистить сообщение о состоянии через",
    "What's your status?" : "Укажите свой статус",
    "Set status" : "Установить статус",
    "Online status" : "Статус работы в сети",
    "Status message" : "Описание статуса",
    "Clear status message" : "Удалить описание статуса",
    "Set status message" : "Установить описание статуса",
    "There was an error saving the status" : "Не удалось сохранить статус",
    "There was an error clearing the status" : "Не удалось убрать статус",
    "No recent status changes" : "Недавние изменения статуса отсуствуют ",
    "Away" : "Отошёл",
    "Do not disturb" : "Не беспокоить",
    "{status}, {timestamp}" : "{status}, {timestamp}",
    "Don't clear" : "Не очищать",
    "Today" : "Сегодня",
    "This week" : "Эта неделя",
    "Online" : "На связи",
    "Invisible" : "Невидимка",
    "Offline" : "Автономно",
    "There was an error saving the new status" : "Не удалось сохранить новый статус",
    "30 minutes" : "30 минут",
    "1 hour" : "1 час",
    "4 hours" : "4 часа",
    "Mute all notifications" : "Отключить все уведомления",
    "Appear offline" : "Возможно, не в сети",
    "Clear status after" : "Удалить статус через"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
